@@ -27,9 +27,10 @@ THE SOFTWARE.
 from modepy.modes import jacobi, grad_jacobi, simplex_onb, grad_simplex_onb
 from modepy.nodes import equidistant_nodes, warp_and_blend_nodes
 from modepy.matrices import vandermonde, resampling_matrix, differentiation_matrices
-from modepy.quadrature import Quadrature
+from modepy.quadrature import Quadrature, QuadratureRuleUnavailable
 from modepy.quadrature.jacobi_gauss import JacobiGaussQuadrature, LegendreGaussQuadrature
 from modepy.quadrature.xiao_gimbutas import XiaoGimbutasSimplexQuadrature
+from modepy.quadrature.vioreanu_rokhlin import VioreanuRokhlinSimplexQuadrature
 from modepy.quadrature.grundmann_moeller import GrundmannMoellerSimplexQuadrature
 
 from modepy.version import VERSION_TEXT as __version__
@@ -44,9 +45,10 @@ __all__ = [
 
         "vandermonde", "resampling_matrix", "differentiation_matrices",
 
-        "Quadrature",
+        "Quadrature", "QuadratureRuleUnavailable",
         "JacobiGaussQuadrature", "LegendreGaussQuadrature",
         "XiaoGimbutasSimplexQuadrature", "GrundmannMoellerSimplexQuadrature",
+        "VioreanuRokhlinSimplexQuadrature",
         ]
 
 from pytools import MovedFunctionDeprecationWrapper
